<?php
/**
 * @file
 * Implementation of OpenLayers behavior.
 */

/**
 * Ctools plugin definition.
 */
$plugin = array(
  'title' => t('Z Maps: Auto Popup'),
  'description' => t('Shows popup by default for layers that have popup enabled.'),
  'type' => 'layer',
  'behavior' => array(
    'file' => 'zmaps_auto_popup.inc',
    'class' => 'zmaps_auto_popup',
    'parent' => 'openlayers_behavior',
  ),
);

/**
 * CTools plugin class Z Maps Auto Popup
 */
class zmaps_auto_popup extends openlayers_behavior {
  /**
   * Override of options_init().
   */
  function options_init() {
    $options = parent::options_init();
    $options['layers'] = array();
    $options['offset_x'] = 0;
    $options['offset_y'] = 0;
    return $options;
  }

  /**
   * Override of options_form().
   */
  function options_form($defaults = array()) {
    $form = parent::options_form(array());
    
    // Only prompt for vector layers
    $vector_layers = array();
    foreach ($this->map['layers'] as $id => $name) {
      $layer = openlayers_layer_load($id);
      if (isset($layer->data['vector']) && $layer->data['vector'] == TRUE) {
        $vector_layers[$id] = $name;
      }
    }
    
    $form['layers'] = array(
      '#title' => t('Auto Popup Layers'),
      '#type' => 'checkboxes',
      '#options' => $vector_layers,
      '#description' => t('Using the newest feature, auto popup for these layers'),
      '#default_value' => isset($defaults['layers']) ? 
        $defaults['layers'] : array(),
    );
    $form['zoom'] = array(
      '#title' => t('Zoom level'),
      '#type' => 'textfield',
      '#description' => t('Zoom level to go to.'),
      '#default_value' => isset($defaults['zoom']) ? $defaults['zoom'] : 3,
    );
    $form['offset_x'] = array(
      '#title' => t('Offest X'),
      '#type' => 'textfield',
      '#description' => t('The number of pixels to offset on the x-axis (longitude).'),
      '#default_value' => isset($defaults['offset_x']) ? 
        $defaults['offset_x'] : 0,
    );
    $form['offset_y'] = array(
      '#title' => t('Offest Y'),
      '#type' => 'textfield',
      '#description' => t('The number of pixels to offset on the y-axis (latitude).'),
      '#default_value' => isset($defaults['offset_y']) ? 
        $defaults['offset_y'] : 0,
    );
    
    return $form;
  }
  
  /**
   * Render.
   */
  function render(&$map) {
    drupal_add_js(drupal_get_path('module', 'zmaps') 
      .'/openlayers_plugins/behaviors/zmaps_auto_popup.js');
    return $this->options;  }
}
