/**
 * @file
 * JS Implementation of OpenLayers behavior.
 */

/**
 * Z Maps OL Behavior: Auto Popup
 */
(function($) {
  Drupal.behaviors.zmaps_auto_popup = {
    'attach': function(context, settings) {
      var data = $(context).data('openlayers');
      if (data && data.map.behaviors['zmaps_auto_popup']) {
        var options = data.map.behaviors['zmaps_auto_popup'];
        var map = data.openlayers;

        // Find select control
        var control = map.getControlsByClass('OpenLayers.Control.SelectFeature');
        control = (control.length > 0) ? control[0] : null;

        // Get the selected layers
        for (var i in options.layers) {
          if (options.layers[i]) {
            var selectedLayer = map.getLayersBy('drupalID', i);
            if (typeof selectedLayer[0] != 'undefined' && 
              typeof selectedLayer[0].features != 'undefined') {
              
              // Clone features and get the last one.
              var features = $.extend(true, [], selectedLayer[0].features);
              if (features.length > 0) {
                var feature = features.pop();
                
                if (control) {
                  map.zoomTo(parseFloat(options.zoom));
                  map.setCenter(feature.geometry.getBounds().getCenterLonLat());
                  map.moveByPx(parseFloat(options.offset_x), parseFloat(options.offset_y));
                  control.unselectAll();
                  control.clickFeature(feature);

                  // For zoom changer, call custom event.  Unfortunately
                  // the behavior is added after this because it is
                  // alphabetically before it in the file system.  :(
                  var t = setTimeout(function() {
                    $(map.div).trigger('zmap_zoom_change');
                  }, 500);
                }
              }
            }
          }
        }
      }
    },
  };
})(jQuery);
