<?php
/**
 * @file
 * Implementation of OpenLayers behavior.
 */

/**
 * Ctools plugin definition.
 */
$plugin = array(
  'title' => t('Z Maps: Feature Highlighter'),
  'description' => t('Given a list of items, associate them with a feature.  For instance a list of Views and a Views data layer.'),
  'type' => 'layer',
  'behavior' => array(
    'file' => 'zmaps_feature_highlight.inc',
    'class' => 'zmaps_feature_highlight',
    'parent' => 'openlayers_behavior',
  ),
);

/**
 * CTools plugin class Z Maps Feature Highlighter
 */
class zmaps_feature_highlight extends openlayers_behavior {
  /**
   * Override of options_init().
   */
  function options_init() {
    $options = parent::options_init();
    $options['layers'] = array();
    return $options;
  }

  /**
   * Override of options_form().
   */
  function options_form($defaults = array()) {
    $form = parent::options_form(array());
    
    // Only prompt for vector layers
    $vector_layers = array();
    foreach ($this->map['layers'] as $id => $name) {
      $layer = openlayers_layer_load($id);
      if (isset($layer->data['vector']) && $layer->data['vector'] == TRUE) {
        $vector_layers[$id] = $name;
      }
    }
    
    $form['layers'] = array(
      '#tree' => TRUE,
    );

    // We want options per layer
    foreach ($vector_layers as $id => $name) {
      $form['layers'][$id] = array(
        '#tree' => TRUE,
        '#type' => 'fieldset',
        '#title' => $name,
      );
      $form['layers'][$id]['enabled'] = array(
        '#title' => t('Enable'),
        '#type' => 'checkbox',
        '#description' => t('Enable layer: %name', array('%name' => $name)),
        '#default_value' => isset($defaults['layers'][$id]['enabled']) ? 
          $defaults['layers'][$id]['enabled'] : FALSE,
      );
      $form['layers'][$id]['container'] = array(
        '#title' => t('List Item Container'),
        '#type' => 'textfield',
        '#description' => t('The jQuery selector for the container of each item.  This would usally be the Views row selctor.'),
        '#default_value' => isset($defaults['layers'][$id]['container']) ? 
          $defaults['layers'][$id]['container'] : '',
      );
      $form['layers'][$id]['link'] = array(
        '#title' => t('List Link Item'),
        '#type' => 'textfield',
        '#description' => t('The jQuery selector for the item that will be clickable.  This is probably a Views title field.'),
        '#default_value' => isset($defaults['layers'][$id]['link']) ? 
          $defaults['layers'][$id]['link'] : '',
      );
      $form['layers'][$id]['feature_search'] = array(
        '#title' => t('List Feature Search ID'),
        '#type' => 'textfield',
        '#description' => t('The jQuery selector for the item that will be used to search for the specific feature.  For instance an Nid field.'),
        '#default_value' => isset($defaults['layers'][$id]['feature_search']) ? 
          $defaults['layers'][$id]['feature_search'] : '',
      );
      $form['layers'][$id]['attribute'] = array(
        '#title' => t('Feature Attribute'),
        '#type' => 'textfield',
        '#description' => t('The atrribute identifier of the feature to search for.  This is usually an extra field on the Data Overlay View.'),
        '#default_value' => isset($defaults['layers'][$id]['attribute']) ? 
          $defaults['layers'][$id]['attribute'] : '',
      );
      $form['layers'][$id]['zoom'] = array(
        '#title' => t('Zoom level'),
        '#type' => 'textfield',
        '#description' => t('The zoom level when moving to the specific feature.'),
        '#default_value' => isset($defaults['layers'][$id]['zoom']) ? 
          $defaults['layers'][$id]['zoom'] : 2,
      );
      $form['layers'][$id]['offset_x'] = array(
        '#title' => t('Offest X'),
        '#type' => 'textfield',
        '#description' => t('The number of pixels to offset on the x-axis (longitude).'),
        '#default_value' => isset($defaults['layers'][$id]['offset_x']) ? 
          $defaults['layers'][$id]['offset_x'] : 0,
      );
      $form['layers'][$id]['offset_y'] = array(
        '#title' => t('Offest Y'),
        '#type' => 'textfield',
        '#description' => t('The number of pixels to offset on the y-axis (latitude).'),
        '#default_value' => isset($defaults['layers'][$id]['offset_y']) ? 
          $defaults['layers'][$id]['offset_y'] : 0,
      );
    }
    
    return $form;
  }
  
  /**
   * Render.
   */
  function render(&$map) {
    drupal_add_js(drupal_get_path('module', 'zmaps') 
      .'/openlayers_plugins/behaviors/zmaps_feature_highlight.js');
    return $this->options;
  }
}
