/**
 * @file
 * JS Implementation of OpenLayers behavior.
 */

/**
 * Z Maps OL Behavior: Feature Highlighter
 */
(function($) {
  Drupal.behaviors.zmaps_feature_highlight = {
    'attach': function(context, settings) {
      var data = $(context).data('openlayers');
      if (data && data.map.behaviors['zmaps_feature_highlight']) {
        var options = data.map.behaviors['zmaps_feature_highlight'];
        var map = data.openlayers;
        var layers = [];
        var idCount = 0;
        
        // Find select control
        var control = map.getControlsByClass('OpenLayers.Control.SelectFeature');
        control = (control.length > 0) ? control[0] : null;

        // Get the selected layers
        for (var i in options.layers) {
          if (options.layers[i].enabled) {
            var selectedLayer = map.getLayersBy('drupalID', i);
            if (typeof selectedLayer[0] != 'undefined') {
              
              // Now, add the link between items and feature
              $(options.layers[i].container).each(function() {
                var $container = $(this);
                var sendData = jQuery.extend({}, options.layers[i]);;
                idCount++;
                
                // Get and Attach data to element
                sendData.containerClass = 'zmapsHighligher-' + idCount;
                sendData.toMatch = $container.find(sendData.feature_search).html();
                sendData.feature = selectedLayer[0].getFeaturesByAttribute(sendData.attribute, sendData.toMatch);
                sendData.feature = (sendData.feature) ? sendData.feature[0] : null;
                $container.addClass(sendData.containerClass);
                $container.find(sendData.link).data('zmapsOLFeature', sendData);
                
                // Click event
                $container.find(sendData.link).click(function(e) {
                  // Make sure we are not taken anywhere.
                  e.preventDefault();
                  
                  // Add class incase some styling is needed.  Also, take away any
                  // other styling
                  $('.zmaps-feature-highlight-link-activated')
                    .removeClass('zmaps-feature-highlight-link-activated');
                  $(this).addClass('zmaps-feature-highlight-link-activated');
                  
                  // Handle opening up popup
                  var elementData = $(this).data('zmapsOLFeature');
                  if (typeof elementData.feature != 'undefined' && elementData.feature) {
                    if (control) {
                      map.zoomTo(parseFloat(elementData.zoom));
                      //map.panTo(elementData.feature.geometry.getBounds().getCenterLonLat());
                      map.setCenter(elementData.feature.geometry.getBounds().getCenterLonLat());
                      map.moveByPx(parseFloat(elementData.offset_x), parseFloat(elementData.offset_y));
                      control.unselectAll();
                      control.clickFeature(elementData.feature);
                      
                      // For zoom changer, call custom event.
                      $(map.div).trigger('zmap_zoom_change');
                    }
                  }
                });
              });
              
            }
          }
        }
      }
    },
  };
})(jQuery);
