<?php
/**
 * @file
 * Implementation of OpenLayers behavior.
 */

/**
 * Ctools plugin definition.
 */
$plugin = array(
  'title' => t('Z Maps: Page Based Visibility'),
  'description' => t('Shows and hides layers based on page (like blocks).'),
  'type' => 'layer',
  'behavior' => array(
    'file' => 'zmaps_page_visbility.inc',
    'class' => 'zmaps_page_visbility',
    'parent' => 'openlayers_behavior',
  ),
);

/**
 * CTools plugin class Z Maps Page Visbility
 */
class zmaps_page_visbility extends openlayers_behavior {
  /**
   * Override of options_init().
   */
  function options_init() {
    $options = parent::options_init();
    $options['layers'] = array();
    return $options;
  }

  /**
   * Override of options_form().
   */
  function options_form($defaults = array()) {
    $form = parent::options_form(array());
    
    // Only prompt for vector layers
    $vector_layers = array();
    foreach ($this->map['layers'] as $id => $name) {
      $layer = openlayers_layer_load($id);
      if (isset($layer->data['vector']) && $layer->data['vector'] == TRUE) {
        $vector_layers[$id] = $name;
      }
    }
    
    $form['layers'] = array(
      '#tree' => TRUE,
    );

    // We want options per layer
    foreach ($vector_layers as $id => $name) {
      $form['layers'][$id] = array(
        '#tree' => TRUE,
        '#type' => 'fieldset',
        '#title' => $name,
      );
      $form['layers'][$id]['show'] = array(
        '#title' => t('Show'),
        '#type' => 'textarea',
        '#description' => t('Show layer, %name, on these pages.  (Hide settings have precedence)', array('%name' => $name)),
        '#default_value' => isset($defaults['layers'][$id]['show']) ? 
          $defaults['layers'][$id]['show'] : FALSE,
      );
      $form['layers'][$id]['hide'] = array(
        '#title' => t('Hide'),
        '#type' => 'textarea',
        '#description' => t('Hide layer, %name, on these pages.  (Hide settings have precedence)', array('%name' => $name)),
        '#default_value' => isset($defaults['layers'][$id]['hide']) ? 
          $defaults['layers'][$id]['hide'] : FALSE,
      );
    }
    
    return $form;
  }
  
  /**
   * Render.
   */
  function render(&$map) {
    if (!empty($map['behaviors']['zmaps_page_visbility'])) {
      foreach ($map['behaviors']['zmaps_page_visbility']['layers'] as $layer => $visibility) {
        $activated = $map['layer_activated'][$layer] ? TRUE : FALSE;
        
        // Determine show.
        if (!empty($visibility['show'])) {
          $activated = drupal_match_path(current_path(), $visibility['show']);
        }
        
        // Determine hide
        if (!empty($visibility['hide'])) {
          $activated = !drupal_match_path(current_path(), $visibility['hide']);
        }
        
        // Set activation
        $map['layer_activated'][$layer] = $activated ? $layer : FALSE;
      }
    }
    
    return $this->options;
  }
}
