<?php
/**
 * @file
 * Implementation of OpenLayers behavior.
 */

/**
 * Ctools plugin definition.
 */
$plugin = array(
  'title' => t('Z Maps: Popup and Rollover'),
  'description' => t('Creates a combination of Popup and rollover functionality, as there are limitations with the OpenLayers Select Feature control.'),
  'type' => 'layer',
  'behavior' => array(
    'file' => 'zmaps_popup_rollover.inc',
    'class' => 'zmaps_popup_rollover',
    'parent' => 'openlayers_behavior',
  ),
);

/**
 * CTools plugin class Z Maps Popup and Rollover combination.
 */
class zmaps_popup_rollover extends openlayers_behavior {
  /**
   * Override of options_init().
   */
  function options_init() {
    $options = parent::options_init();
    $options['popup'] = FALSE;
    $options['rollover'] = FALSE;
    $options['layers'] = array();
    return $options;
  }

  /**
   * Override of options_form().
   */
  function options_form($defaults = array()) {
    $form = parent::options_form(array());
    
    // Only prompt for vector layers
    $vector_layers = array();
    foreach ($this->map['layers'] as $id => $name) {
      $layer = openlayers_layer_load($id);
      if (isset($layer->data['vector']) && $layer->data['vector'] == TRUE) {
        $vector_layers[$id] = $name;
      }
    }

    $form['popup'] = array(
      '#title' => t('Enable Popup'),
      '#type' => 'checkbox',
      '#description' => t('Select this if you want to enable popups.'),
      '#default_value' => isset($defaults['popup']) ? 
        $defaults['popup'] : $this->options['popup'],
    );
    $form['rollover'] = array(
      '#title' => t('Enable Rollovers'),
      '#type' => 'checkbox',
      '#description' => t('Select this if you want to enable rollovers.'),
      '#default_value' => isset($defaults['rollover']) ? 
        $defaults['rollover'] : $this->options['rollover'],
    );
    $form['layers'] = array(
      '#title' => t('Layers'),
      '#type' => 'checkboxes',
      '#options' => $vector_layers,
      '#description' => t('Select layers to apply to.'),
      '#default_value' => isset($defaults['layers']) ? 
        $defaults['layers'] : $this->options['layers'],
    );
    
    return $form;
  }
  
  /**
   * Render.
   */
  function render(&$map) {
    drupal_add_css(drupal_get_path('module', 'zmaps') 
      .'/openlayers_plugins/behaviors/zmaps_popup_rollover.css');
    drupal_add_js(drupal_get_path('module', 'zmaps') 
      .'/openlayers_plugins/behaviors/zmaps_popup_rollover.js');
    return $this->options;
  }
}
