/**
 * @file
 * JS Implementation of OpenLayers behavior.
 */

/**
 * Z Maps OL Behavior: popup and tooltip
 */
(function($) {
  Drupal.behaviors.zmaps_popup_rollover = {
    'attach': function(context, settings) {
      var data = $(context).data('openlayers');
      if (data && data.map.behaviors['zmaps_popup_rollover']) {
        var options = data.map.behaviors['zmaps_popup_rollover'];
        var map = data.openlayers;
        var layers = [];

        // Get the selected layers
        for (var i in options.layers) {
          var selectedLayer = map.getLayersBy('drupalID', options.layers[i]);
          if (typeof selectedLayer[0] != 'undefined') {
            layers.push(selectedLayer[0]);
          }
        }

        // Utilize select feature control
        var control = new OpenLayers.Control.SelectFeature(layers, {
          activeByDefault: true,
          highlightOnly: false,
          onSelect: this.select,
          onUnselect: this.unselect,
          multiple: false,
          hover: true,
          callbacks: {
            'click': this.click,
            'over': this.over,
            'out': this.out
          }
        });
        map.addControl(control);
        control.activate();
      }
    },
    
    'select': function(feature) {
    
    },
    
    'unselect': function(feature) {
      // Remove popup if feature is unselected.
      if (feature.popup) {
        feature.layer.map.removePopup(feature.popup);
        feature.popup.destroy();
        feature.popup = null;
      }
    },
    
    'click': function(feature) {
      // Create content
      var popup = Drupal.behaviors.zmaps_popup_rollover.popup(feature);
      if (popup) {
        // Remove any rollovers
        Drupal.behaviors.zmaps_popup_rollover.removeRollover(feature);
        
        // Create anchored popup
        popupAnchored = new OpenLayers.Popup.Anchored(
          'zmaps-popup',
          feature.geometry.getBounds().getCenterLonLat(),
          null,
          popup,
          null,
          true,
          function(e) {
            // Close all popups
            if (feature.layer.map.popups) {
              for (var x in feature.layer.map.popups) {
                feature.layer.map.removePopup(feature.layer.map.popups[x]);
              }
            }
          }
        );

        // Properties
        popupAnchored.setBackgroundColor('transparent');
        popupAnchored.autoSize = true;

        // Assign popup to feature and map.
        feature.popup = popupAnchored;
        feature.layer.map.addPopup(popupAnchored);
        Drupal.attachBehaviors();
      }
    
    },
    
    'over': function(feature) {
      // Create content
      var rollover = Drupal.behaviors.zmaps_popup_rollover.rollover(feature);
      if (rollover) {
        Drupal.behaviors.zmaps_popup_rollover.add(feature, rollover);
      }
    },
    
    'out': function(feature) {
      Drupal.behaviors.zmaps_popup_rollover.removeRollover(feature);
    },
    
    'rollover': function(feature) {
      var text = '';
      if (feature.attributes.name) {
        text += 
          '<div class="zmaps-rollover">' +
            '<div class="zmaps-rollover-inner">' +
              '<div class="zmaps-rollover-inner-inner">' +
                '<div class="zmaps-rollover-name">' + feature.attributes.name + '</div>' +
              '</div>' +
            '</div>' +
          '</div>';
      }
      return $(text);
    },
    
    'popup': function(feature) {
      var text = '';
      var name = feature.attributes.name ? feature.attributes.name : '';
      var description = feature.attributes.description ? feature.attributes.description : '';
      
      text += 
        '<div class="zmaps-popup">' + 
          '<div class="zmaps-popup-inner">' + 
            '<div class="zmaps-popup-inner-inner">' + 
              '<div class="zmaps-popup-name">' + name + '</div>' +
              '<div class="zmaps-popup-description">' + description + '</div>' +
            '</div>' +
          '</div>' +
          '</div>';
      return text;
    },
    
    'add': function(feature, content, offsetX, offsetY) {
      offsetX = offsetX || 0;
      offsetY = offsetY || 0;
    
      // Create offset
      var point = new OpenLayers.LonLat(
        feature.geometry.x + offsetX, feature.geometry.y + offsetY
      );
      var offset = feature.layer.getViewPortPxFromLonLat(point);
      
      // Position
      $(content).css({
        zIndex: '1000',
        position: 'absolute',
        left: offset.x,
        top: offset.y
      });
      
      // Add to map
      $(feature.layer.map.div)
        .append(content);
    },
    
    'removeRollover': function(feature) {
      $(feature.layer.map.div).children('div.zmaps-rollover')
        .fadeOut('fast', function() {
          $(this).remove();
        });
    },
    
    'removePopup': function(feature) {
      $(feature.layer.map.div).children('div.zmaps-popup')
        .fadeOut('fast', function() {
          $(this).remove();
        });
    }
  };
})(jQuery);
