<?php
/**
 * @file
 * Implementation of OpenLayers behavior.
 */

/**
 * Ctools plugin definition.
 */
$plugin = array(
  'title' => t('Z Maps: Zoom Layer Changer'),
  'description' => t('Changes layer based on zoom level.  Right now, it just 
    works for changing the base layer.  Also, the zoom levels are just assumed 
    and not actually determined by the layers that are available for 
    this map.'),
  'type' => 'layer',
  'behavior' => array(
    'file' => 'zmaps_zoom_layer_changer.inc',
    'class' => 'zmaps_zoom_layer_changer',
    'parent' => 'openlayers_behavior',
  ),
);

/**
 * CTools plugin class Z Maps Zoom Layer Changer
 */
class zmaps_zoom_layer_changer extends openlayers_behavior {
  /**
   * Override of options_init().
   */
  function options_init() {
    $options = parent::options_init();
    $options['zooms'] = array();
    $options['zoom_offsets'] = array();
    return $options;
  }

  /**
   * Override of options_form().
   */
  function options_form($defaults = array()) {
    $form = parent::options_form(array());

    // Only prompt for vector layers
    $base_layers = array();
    foreach ($this->map['layers'] as $id => $name) {
      $layer = openlayers_layer_load($id);
      if (!isset($layer->data['vector']) || $layer->data['vector'] != TRUE) {
        $base_layers[$id] = $layer->title;
      }
    }
    
    // For now just use arbitrary zoom levels
    $zoom_levels = 20;
    
    // Make each zoom level an option
    $form['zooms'] = array(
      '#tree' => TRUE,
    );
    foreach (range(0, $zoom_levels) as $zl) {
      $form['zooms'][$zl] = array(
        '#title' => t('Zoom level @level', array('@level' => $zl)),
        '#type' => 'select',
        '#options' => $base_layers,
        '#default_value' => isset($defaults['zooms'][$zl]) ? 
          $defaults['zooms'][$zl] : $this->map['default_layer'],
      );
    }
    
    return $form;
  }
  
  /**
   * Render.
   */
  function render(&$map) {
    drupal_add_js(drupal_get_path('module', 'zmaps') 
      .'/openlayers_plugins/behaviors/zmaps_zoom_layer_changer.js');
    return $this->options;
  }
}
